# PhosKhemia

A library for the handling and analysis of spectroscopic data.

## Use Cases

PhosKhemia is a library with routines and utilities for the analysis
of UV-Vis absorption spectra, steady-state fluorescence data,
nanosecond transient absorption spectra, time-correlated single-photon
counting, and various other spectra.

## Installation

```python
pip install phoskhemia
```

## Bugs and Feedback

As this library is still under construction, feel free to reach out if
there are any bugs, issues, or for general feedback.
